@@ -1,17 +1,19 @@
 mod common;
+
 use common::*;
 use serde::{Deserialize, Serialize};
 
 #[derive(Serialize, Deserialize, PartialEq, Debug)]
 struct DesiredShape {
     num_field: usize,
+
     string_field: String,
 }
 
 impl Shape for DesiredShape {
     type Err = Error;
     fn shape(m: &Message) -> Result<DesiredShape, Error> {
-        serde_json::from_slice(m.get_body()?.as_ref()).map_err(|e| Error::SerdeError(e))
+        serde_json::from_slice(m.get_body()?.as_ref()).map_err(Error::SerdeError)
     }
 }
 
@@ -22,7 +24,7 @@ fn shape_desired_test() {
         num_field: 42,
         string_field: "important data".into(),
     };
-    let m = Message::new().set_body(serde_json::to_string(&initial_shape).unwrap().as_bytes());
+    let m = Message::new().body(&serde_json::to_string(&initial_shape).unwrap());
 
     // -- pack, send, receive happens here
 
